# Security Policy

## Reporting a Vulnerability

Please report security vulnerabilities through [GitHub Security Advisories](https://github.com/ProductOfAmerica/mcp-server-kicad/security/advisories/new).

**Do not report security issues via public GitHub issues.**

You will receive a response acknowledging your report within 72 hours. The advisory will be used to coordinate a fix and disclosure timeline.
